#!/usr/bin/env python3
"""Progression game script."""


from brain_games.engine import run_game
from brain_games.games import progression


def main():
    """Progression game script."""
    run_game(progression)


if __name__ == '__main__':
    main()
